@@ -26,7 +26,7 @@ def _handle_req_ret(period, report_type, code, market):
     # 基础财务数据: 公共统一处理请求和返回数据
     if t_typeof(code) != 'str':return '您好,该财务数据接口只允许获取单个合约的数据喔'
     if market == 'usa':return '您好,接口暂时不提供美股的数据哟,我们会马不停蹄的加班,尽快把美股的数据补全!'
-
+    if code is None or t_typeof(code) is not str:return '您好, 请填写code字段！'
     body = {
         "reportType": report_type,
         "periodMark": period,
@@ -37,7 +37,7 @@ def _handle_req_ret(period, report_type, code, market):
     _df_ = total_handle_req(body=body, URL=BASIC_FIN_POST_URL)
     return _df_
 
-def get_basic_fin_data(code='00700', market='hkg', period=12, report_type='1'):
+def get_basic_fin_data(code='00700', market='hkg', period=12):
     '''
     periodMark	integer($int32) null-全部 3-一季度，6-半年度，9-三季度，12-年度
     reportType	string 1：主要指标
@@ -47,11 +47,12 @@ def get_basic_fin_data(code='00700', market='hkg', period=12, report_type='1'):
         df:
         主要财务指标  季度/年度的财务数据
     '''
+    report_type = '1'
     basic_fin_df = _handle_req_ret(period, report_type, code, market)
 
     return basic_fin_df
 
-def get_income_fin_data(code='00700', market='hkg', period=12, report_type='2'):
+def get_income_fin_data(code='00700', market='hkg', period=12):
     '''
     Args:
         code: string 股票代码
@@ -62,11 +63,12 @@ def get_income_fin_data(code='00700', market='hkg', period=12, report_type='2'):
         df:
         income 季度/年度的财务数据
     '''
+    report_type = '2'
     income_fin_df = _handle_req_ret(period, report_type, code, market)
 
     return income_fin_df
 
-def get_balance_fin_data(code='00700', market='hkg', period=12, report_type='3'):
+def get_balance_fin_data(code='00700', market='hkg', period=12):
     '''
     Args:
         code: string 股票代码
@@ -77,11 +79,12 @@ def get_balance_fin_data(code='00700', market='hkg', period=12, report_type='3')
         df:
         balance 季度/年度的财务数据
     '''
+    report_type = '3'
     balance_fin_df = _handle_req_ret(period, report_type, code, market)
 
     return balance_fin_df
 
-def get_cashflow_fin_data(code='00700', market='hkg', period=12, report_type='4'):
+def get_cashflow_fin_data(code='00700', market='hkg', period=12):
     '''
     Args:
         code: string 股票代码
@@ -92,6 +95,7 @@ def get_cashflow_fin_data(code='00700', market='hkg', period=12, report_type='4'
         df
         cashflow  季度/年度的财务数据
     '''
+    report_type = '4'
     cashflow_fin_df = _handle_req_ret(period, report_type, code, market)
 
     return cashflow_fin_df
