@@ -404,7 +404,7 @@ def get_stoq_factor_data(code_list=['00700'], market=2, unit='1d', start_date=No
             fre:是否复权 默认不复权
         Returns: 返回macd的因子数据
     '''
-    factor_names = ['secu_code', 'Stoq', 'trading_day']
+    factor_names = ['secu_code', 'stoq', 'trading_day']
     data_type = 'derived'
     # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
     # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
