@@ -36,8 +36,9 @@ WEBSOCKET_TRADE_HOST = "wss://__kaisarooturl__/kgl-trade-push-service/ws"
 
 openapi_scope = "wthk"
 openapi_scope = "read"
-
-MARKET_POST_URL = "https://sit-kgl.jt00000.com/kgl-stock-push-provider"
+# < 2120-04-07 => "https://sit-kgl.jt00000.com/kgl-stock-push-provider"
+# > 2120-04-07 => https://sit-kgl.jt00000.com/kgl-stock-support-provider
+MARKET_POST_URL = "https://sit-kgl.jt00000.com/kgl-stock-support-provider"
 MARKET_WS_URL = "ws://sit-stock-gateway.jt00000.com/stock-front/stock" #"ws://uat-stock.jt00000.com/stock"
 
 # 基础财务指标URL, Post
